import Async from "typescene-async";
import Activity, { ResourceActivity } from "./Activity";
export declare type PathInitializerPart = ResourceActivity | ActivityResourcePath | string;
/** Represents a resource path (URL/hash segment) that is handled by one or more activities */
export declare class ActivityResourcePath {
    /** Create a new resource path from given parts (string, ResourceActivity instance, or another resource path) */
    constructor(...parts: PathInitializerPart[]);
    /** Append a part to the end of this path and return new path */
    concat(...parts: PathInitializerPart[]): ActivityResourcePath;
    /** Returns the URL that can be used e.g. in href attributes; does not contain final slash so can be concatenated */
    toString(): any;
    /** Check if given URL or path (e.g. http://... or /... or #/...) matches this path (or a sub path); returns matching prefix and remainder if matched successfully, undefined otherwise */
    match(location: string): ActivityResourcePath.Match | undefined;
    private _parts;
}
export declare namespace ActivityResourcePath {
    /** Information for a resource path match */
    interface Match {
        /** The path name or hash prefix that was matched */
        location: string;
        /** The remainder of the location after the matching prefix, without leading slash (if any) */
        remainder: string;
        /** True if location matched by hash (part after #/...) */
        isHash: boolean;
    }
}
/** Represents a mapping of paths to activity providers (routes) */
export declare class ActivityResourceMap {
    /** Add a route that invokes given callback with parameters that correspond to the parts of the path remainder when current location matches with given path (#/... or /...); the final parameter is set to all remaining parts joined with slashes (glob); if the callback has no parameters, an exact match is required; returns a signal connection that can be used to unregister */
    register(path: PathInitializerPart | PathInitializerPart[], callback: (...params: string[]) => Activity | Activity[] | PromiseLike<Activity | Activity[]>): Async.SignalConnection;
    /** Get a promise that resolves to a list of activities that are registered for given path (#/... or /... or full href, %-decoded) */
    obtainAsync(location: string | ActivityResourcePath): PromiseLike<Activity[]>;
    /** Get a function that matches a location with given resource path and calls callback with location remainder */
    private _getMatcher(resourcePath, callback);
    private _Signal;
}
