import Async from "typescene-async";
import Component from "./Component";
/** Represents a property binding, used by component factories to proxy properties on sub components to values taken from the base component instance */
export declare class Binding<ResultT> {
    /** Create a new binding based on the given property name/path (referring to the base component, on which .with or .initializeWith was called; e.g. "x", "!selected", or "activity.title", values can also be instances of ObservableValue or Promise), and optionally one or two transformation functions (for getter and/or setter) */
    constructor(sourcePath?: string, getTransform?: (value: any) => (ResultT | Async.ObservableValue<ResultT> | PromiseLike<ResultT>));
    /** Make an ObservableValue that is bound to the value on given component (used by factory initializer to apply binding) */
    observeOn(component: Component, name: string): Async.ObservableValue<ResultT>;
    private _fget;
}
/** Represents a two-way binding (Binding that also applies a setter) */
export declare class TwoWayBinding<ResultT> extends Binding<ResultT> {
    constructor(sourcePath?: string, getTransform?: (value: any) => (ResultT | Async.ObservableValue<ResultT> | PromiseLike<ResultT>), setTransform?: (value: any) => any);
    observeOn(component: Component, name: string): Async.ObservableValue<ResultT>;
    private _fset;
}
/** Shortcut to create a new Binding with given argument */
export declare function bind(sourcePath?: string): Binding<any>;
/** Shortcut to create a new Binding with given arguments */
export declare function bind<T>(sourcePath: string, getTransform: (value: any) => T): Binding<T>;
/** Shortcut to create a new TwoWayBinding with given argument */
export declare function bind2(sourcePath?: string): TwoWayBinding<any>;
/** Shortcut to create a new TwoWayBinding with given arguments */
export declare function bind2<T>(sourcePath: string, getTransform: (value: any) => T, setTransform?: (value: any) => any): Binding<T>;
export default Binding;
