import Async from "typescene-async";
import Component from "../Component";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
import { ComponentRenderHtmlOutput } from "../ComponentRenderOutput";
/** Block base class: full-width horizontal block element */
export declare class Block extends Component {
    /** Create a new block component with given content */
    constructor(...blocks: (HTMLElement | Block | Async.ObservableValue<HTMLElement> | Async.ObservableValue<Block>)[]);
    /** Create a new block component with elements from the given DOM fragment */
    constructor(documentFragment: DocumentFragment);
    /** Initialize a block factory with given values */
    static with: (values: Block.Initializer) => ComponentFactory<Block>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: Block.Initializer) => this;
    /** Rendered output for this component (observable) */
    out: ComponentRenderHtmlOutput;
    /** Block Height (CSS value), default auto (observed) */
    height: string;
    /** Set to true by List when this element is selected (observable); setting this to true does NOT select the item in a list */
    selected: boolean;
    /** True if mouse is hovering over this block (read-only observable) */
    readonly hoverState: boolean | undefined;
    /** True if any inner control element has focus (read-only observable) */
    readonly hasFocus: boolean | undefined;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
    private _inner;
    private _hasFocus;
    private _hoverState;
}
export declare namespace Block {
    /** Initializer for .with({...}) */
    interface Initializer extends Component.Initializer {
        /** Property initializer */
        height?: ValueOrAsync<string>;
    }
}
export default Block;
