import Block from "./Block";
import { Container } from "../";
import Component from "../Component";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
/** Represents a block with an embedded sub container within its margins/padding */
export declare class ContainerBlock<ContainerT extends Container> extends Block {
    /** Create a container block component with given container, if any */
    constructor(container?: ContainerT | Container);
    /** Initialize a container block factory with given values */
    static with<ContainerT extends Container>(values: ContainerBlock.Initializer<ContainerT>): ComponentFactory<ContainerBlock<ContainerT>>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: ContainerBlock.Initializer<ContainerT>) => this;
    /** Container element (created by constructor, but may be modified, may be null, defaults to plain Container; observed); LayoutContainer components need a fixed height, default 100% */
    container: ContainerT | null;
    /** Height (CSS value), default auto (observed) */
    height: string;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
}
export declare namespace ContainerBlock {
    /** Initializer for .with({ ... }) */
    interface Initializer<ContainerT extends Container> extends Block.Initializer {
        /** Property initializer */
        container: ValueOrAsync<ComponentFactory<Container> | Container> | ComponentFactory.SpecList2 | null;
        /** Property initializer */
        height?: ValueOrAsync<string>;
    }
}
export default ContainerBlock;
