import Style from "../../Style";
import Block from "./Block";
import { ControlElement } from "../";
import Component from "../Component";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
/** Represents a row within a table */
export declare class TableRow extends Block {
    /** Create a table row with given columns, if any */
    constructor(columns?: (string | ControlElement | Block)[], widths?: string[], styles?: (Style | Style.StyleSet)[]);
    /** Initialize a table row/header factory with given values */
    static with(values: TableRow.Initializer): ComponentFactory<TableRow>;
    /** Initialize a table row/header factory with given columns */
    static withColumns(columns: ComponentFactory.SpecList): ComponentFactory<TableRow>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: TableRow.Initializer) => this;
    /** The column content as strings or blocks (observed) */
    columns: (string | ControlElement | Block | null | undefined)[];
    /** Column widths for all columns (CSS values, observed) */
    widths: (string | undefined)[];
    /** Other styles for all columns (observed) */
    styles: (Style | Style.StyleSet | null | undefined)[];
    /** Row index (base 0) the last time this row was rendered, or -1 */
    rowIndex: number;
    /** Returns an array of directly contained UI components */
    getChildren(): Component[];
    protected colTagName: string;
}
export declare namespace TableRow {
    /** Initializer for .with({ ... }) */
    interface Initializer extends Block.Initializer {
        /** Property initializer */
        columns: ComponentFactory.SpecListTCol;
        /** Property initializer */
        widths?: ValueOrAsync<(string | undefined)[]>;
        /** Property initializer */
        styles?: ValueOrAsync<Style | Style.StyleSet | undefined | null>[];
    }
}
/** A table header at the top of a table */
export declare class TableHeader extends TableRow {
    protected colTagName: string;
}
export default TableRow;
