import Button from "./Button";
import ControlElement from "./ControlElement";
import { MouseHandler } from "../DOMEvents";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
/** Represents a button group (toggle, tab, or toolbar) control */
export declare class ButtonGroup extends ControlElement {
    /** Create a button group element */
    constructor(buttons?: Button[]);
    /** Initialize a button group control factory with given values */
    static with(values: ButtonGroup.Initializer): ComponentFactory<ButtonGroup>;
    /** Initialize a button group control factory with given buttons/button factories; provide active button index to activate one of the buttons, OR set multiToggle argument to true to allow multiple buttons to be active at once; use ToggleButton instances to activate on click */
    static withButtons(buttons: (Button | ComponentFactory<Button>)[], activeIndex?: number, multiToggle?: boolean, clickHandler?: MouseHandler): ComponentFactory<ButtonGroup>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: ButtonGroup.Initializer) => this;
    /** Buttons to be displayed as part of the button group */
    buttons: (Button | null)[];
    /** Set to true to show buttons from top to bottom */
    vertical: boolean;
    /** Set to false to expand horizontally within row (observed) */
    shrinkwrap: boolean;
    /** Set to false to disable making the active button a primary button; default true (observed) */
    makeActivePrimary: boolean;
    /** Set to true to allow several buttons to be active at the same time; default false, i.e. button group acts as a switch, use ToggleButton instances and .activeIndex on group to find index of active button */
    multiToggle: boolean;
    /** Active button index, only if .multiToggle is not set (read/write, observed) */
    activeIndex: number | undefined;
    /** Activate button using given index, and start associated activity if any; returns this */
    activate(index: number): void;
    /** Watch active index and activate the right button */
    private _watchActiveIndex;
    /** Watch for active buttons and make them primary buttons (others not) */
    private _watchButtons;
}
export declare namespace ButtonGroup {
    /** Initializer for .with({ ... }) */
    interface Initializer extends ControlElement.Initializer {
        /** Property initializer */
        buttons: ComponentFactory.SpecList;
        /** Property initializer */
        activeIndex?: ValueOrAsync<number>;
        /** Property initializer */
        multiToggle?: ValueOrAsync<boolean>;
        /** Property initializer */
        makeActivePrimary?: ValueOrAsync<boolean>;
        /** Property initializer */
        vertical?: ValueOrAsync<boolean>;
    }
}
export default ButtonGroup;
