import { Container } from "../";
import ControlElement from "./ControlElement";
import Component from "../Component";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
/** Represents a control element that contains a container */
export declare class ContainerControl<ContainerT extends Container> extends ControlElement {
    /** Create a container control element that contains the given container, if any */
    constructor(container?: ContainerT | Container);
    /** Initialize a container control element factory with given values */
    static with<ContainerT extends Container>(values: ContainerControl.Initializer): ComponentFactory<ContainerControl<ContainerT>>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: ContainerControl.Initializer) => this;
    /** Container element (created by constructor, but may be modified or set to null; defaults to plain Container; observed); LayoutContainer components need a fixed height, default 100%; if set to a container (other than LayoutContainer) with maxContentWidth other than auto, this control will shrinkwrap to the same width as the container */
    container: ContainerT | null;
    /** Height (CSS value), default auto (observed) */
    height: string;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
    private _hasExplicitWidth;
}
export declare namespace ContainerControl {
    /** Initializer for .with({ ... }) */
    interface Initializer extends ControlElement.Initializer {
        /** Property initializer */
        container: ValueOrAsync<ComponentFactory<Container> | Container> | ComponentFactory.SpecList2 | null;
        /** Property initializer */
        height?: ValueOrAsync<string>;
    }
}
export default ContainerControl;
