import Style from "../../Style";
import ControlElement from "./ControlElement";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
import TextLabelFactory from "../TextLabelFactory";
/** Represents a progress bar control (full width by default) */
export declare class ProgressBar extends ControlElement {
    /** Create a progress bar control element */
    constructor(progress?: number);
    /** Initialize a progress bar control factory with given values */
    static with: (values: ProgressBar.Initializer) => ComponentFactory<ProgressBar>;
    /** Initialize a progress bar control factory with given progress */
    static withProgress(progress: ValueOrAsync<number>): ComponentFactory<ProgressBar>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: ProgressBar.Initializer) => this;
    /** Current progress 0-1 (observed) */
    progress: number;
    /** Tooltip text (title attribute; observed) */
    tooltipTitle: string;
    /** Encapsulation of div.progress-bar element style (observed) */
    readonly style_bar: Style;
    private _barElement;
}
export declare namespace ProgressBar {
    /** Initializer for .with({ ... }) */
    interface Initializer extends ControlElement.Initializer {
        /** Property initializer */
        progress: ValueOrAsync<number>;
        /** Property initializer */
        style_bar?: ValueOrAsync<Style | Style.StyleSet>;
        /** Property initializer */
        tooltipTitle?: ValueOrAsync<string> | TextLabelFactory;
    }
}
export default ProgressBar;
