import Async from "typescene-async";
import { CustomDragEvent } from "../Drag";
/** Interface definition for EventHandler and other handler wrappers */
export interface ActionHandler<DataT, SignalT> {
    /** Call the handler as a function */
    (data?: DataT): void;
    /** Add this EventHandler as a handler for given event signal */
    connectTo(signal: SignalT): Async.SignalConnection;
    /** Always true, to identify EventHandler instances */
    _isEventHandler: boolean;
}
export interface EventHandlerCtor<EventDataT, HandlerT> {
    /** Wrap given function for handling UI events (with value or DOM event) */
    new (handler: (data: EventDataT) => void): HandlerT;
}
/** Base signal type for all DOM events */
export interface DOMEventSignal extends Async.CustomSignalClass<Event, Async.Signal<Event>> {
}
export interface EventHandler extends ActionHandler<Event, DOMEventSignal> {
}
/** Signal that is emitted when a keyboard DOM event occurs */
export interface KeyEventSignal extends Async.CustomSignalClass<KeyboardEvent, Async.Signal<KeyboardEvent>> {
}
export interface KeyHandler extends ActionHandler<KeyboardEvent, KeyEventSignal> {
}
/** Signal that is emitted when a mouse DOM event occurs */
export interface MouseEventSignal extends Async.CustomSignalClass<MouseEvent, Async.Signal<MouseEvent>> {
}
export interface MouseHandler extends ActionHandler<MouseEvent, MouseEventSignal> {
}
/** Signal that is emitted when a custom drag event occurs */
export interface DragEventSignal extends Async.CustomSignalClass<CustomDragEvent, Async.Signal<CustomDragEvent>> {
}
export interface DragHandler extends ActionHandler<CustomDragEvent, DragEventSignal> {
}
/** Signal that is emitted when a focus/blur DOM event occurs */
export interface FocusEventSignal extends Async.CustomSignalClass<FocusEvent, Async.Signal<FocusEvent>> {
}
export interface FocusHandler extends ActionHandler<FocusEvent, FocusEventSignal> {
}
/** Constructor for an event handler (any argument) */
export declare var ActionHandler: EventHandlerCtor<any, ActionHandler<any, any>>;
/** Constructor for a DOM event handler (plain Event argument) */
export declare var EventHandler: EventHandlerCtor<Event, EventHandler>;
/** Constructor for a keyboard event handler */
export declare var KeyHandler: EventHandlerCtor<KeyboardEvent, KeyHandler>;
/** Constructor for a mouse event handler */
export declare var MouseHandler: EventHandlerCtor<MouseEvent, MouseHandler>;
/** Constructor for a mouse event handler */
export declare var DragHandler: EventHandlerCtor<DragEvent, DragHandler>;
/** Constructor for a focus/blur event handler */
export declare var FocusHandler: EventHandlerCtor<FocusEvent, FocusHandler>;
